@@ -287,15 +287,32 @@ class Connection:
         return ssl_ctx
 
     async def ping(self):
-        await self.writer.write_varint(ClientPacket.PING)
-        await self.writer.flush()
-        packet_type = await self.reader.read_varint()
-        while packet_type == ServerPacket.PROGRESS:
-            await self.receive_progress()
+        try:
+            await self.writer.write_varint(ClientPacket.PING)
+            await self.writer.flush()
             packet_type = await self.reader.read_varint()
-        if packet_type != ServerPacket.PONG:
-            msg = self.unexpected_packet_message("Pong", packet_type)
-            raise UnexpectedPacketFromServerError(msg)
+            while packet_type == ServerPacket.PROGRESS:
+                await self.receive_progress()
+                packet_type = await self.reader.read_varint()
+            if packet_type != ServerPacket.PONG:
+                msg = self.unexpected_packet_message("Pong", packet_type)
+                raise UnexpectedPacketFromServerError(msg)
+        except IndexError as e:
+            logger.debug(
+                "Ping package smaller than expected or empty. "
+                "There may be connection or network problems - "
+                "we believe that the connection is incorrect.",
+                exc_info=e,
+            )
+            return False
+        except (ConnectionError, OSError, RuntimeError) as e:
+            # If raised RuntimeError with "TCPTransport the handler is closed" - just returning false,
+            # because this is a connection loss case
+            if isinstance(e, RuntimeError) and "TCPTransport closed=True" not in str(e):
+                raise e
+            logger.debug("Socket closed", exc_info=e)
+            return False
+
         return True
 
     async def receive_data(self, raw=False):
